#!/usr/bin/env ruby
require 'fileutils'

addon = ARGV[0]

# Cmdline Usage
if adon.nil?
  puts "Usage: #{$0} <name of Addon>"
  exit(0)
end

puts "This will create the addon in the current working directory, are you sure you want to do this? [Y|N]"

ans = $stdin.read(1)
if ans =~ /n|N/
  exit(0)
end

FileUtils.mkdir_p "#{addon}"
FileUtils.mkdir_p "#{addon}/Libs"
FileUtils.mkdir_p "#{addon}/Locales"

toc = File.new("#{addon}/#{addon}.toc", modestring="w")
main = File.new("#{addon}/#{addon}.lua", modestring="w")
embeds = File.new("#{addon}/embeds.xml", modestring="w")
locale_xml = File.new("#{addon}/Locales.xml", modestring="w")
pkgmeta = File.new("#{addon}/.pkgmeta", modestring="w")

pkgmeta << "package-as: #{addon}\n\n"
pkgmeta << "tools-used:\n"
pkgmeta << "\t- data-tools # same as data-tools/mainline\n\n"
pkgmeta << "license-output: LICENSE.txt\n"
pkgmeta.close

en_locale = File.new("#{addon}/Locales/#{addon}-enUS.lua", modestring="w")
en_locale << "local debug = false\n--@debug@\ndebug = true\n--@end-debug@\n"
en_locale << "local L = LibStub(\"AceLocale-3.0\"):NewLocale(\"#{addon}\",\"enUS\",true,debug)\n"
en_locale << "--@localization(locale=\"enUS\", format=\"lua_additive_table\", same-key-is-true=true, namespace=\"App\", table-name=\"L\", handle-unlocalized=\"comment\")@\n"
en_locale.close

de_locale = File.new("#{addon}/Locales/#{addon}-deDE.lua", modestring="w")
de_locale << "local L = LibStub(\"AceLocale-3.0\"):NewLocale(\"#{addon}\",\"deDE\")\n"
de_locale << "if not L then return end\n"
de_locale << "--@localization(locale=\"deDE\", format=\"lua_additive_table\", namespace=\"App\", table-name=\"L\", handle-unlocalized=\"comment\")@\n"
de_locale.close

es_locale = File.new("#{addon}/Locales/#{addon}-esES.lua", modestring="w")
es_locale << "local L = LibStub(\"AceLocale-3.0\"):NewLocale(\"#{addon}\",\"esES\")\n"
es_locale << "if not L then return end\n"
es_locale << "--@localization(locale=\"esES\", format=\"lua_additive_table\", namespace=\"App\", table-name=\"L\", handle-unlocalized=\"comment\")@\n"
es_locale.close

em_locale = File.new("#{addon}/Locales/#{addon}-esMX.lua", modestring="w")
em_locale << "local L = LibStub(\"AceLocale-3.0\"):NewLocale(\"#{addon}\",\"esMX\")\n"
em_locale << "if not L then return end\n"
em_locale << "--@localization(locale=\"esMX\", format=\"lua_additive_table\", namespace=\"App\", table-name=\"L\", handle-unlocalized=\"comment\")@\n"
em_locale.close

fr_locale = File.new("#{addon}/Locales/#{addon}-frFR.lua", modestring="w")
fr_locale << "local L = LibStub(\"AceLocale-3.0\"):NewLocale(\"#{addon}\",\"frFR\")\n"
fr_locale << "if not L then return end\n"
fr_locale << "--@localization(locale=\"frFR\", format=\"lua_additive_table\", namespace=\"App\", table-name=\"L\", handle-unlocalized=\"comment\")@\n"
fr_locale.close

ko_locale = File.new("#{addon}/Locales/#{addon}-koKO.lua", modestring="w")
ko_locale << "local L = LibStub(\"AceLocale-3.0\"):NewLocale(\"#{addon}\",\"koKR\")\n"
ko_locale << "if not L then return end\n"
ko_locale << "--@localization(locale=\"koKR\", format=\"lua_additive_table\", namespace=\"App\", table-name=\"L\", handle-unlocalized=\"comment\")@\n"
ko_locale.close

cn_locale = File.new("#{addon}/Locales/#{addon}-znCN.lua", modestring="w")
cn_locale << "local L = LibStub(\"AceLocale-3.0\"):NewLocale(\"#{addon}\",\"znCN\")\n"
cn_locale << "if not L then return end\n"
cn_locale << "--@localization(locale=\"znCN\", format=\"lua_additive_table\", namespace=\"App\", table-name=\"L\", handle-unlocalized=\"comment\")@\n"
cn_locale.close

tw_locale = File.new("#{addon}/Locales/#{addon}-znTW.lua", modestring="w")
tw_locale << "local L = LibStub(\"AceLocale-3.0\"):NewLocale(\"#{addon}\",\"znTW\")\n"
tw_locale << "if not L then return end\n"
tw_locale << "--@localization(locale=\"znTW\", format=\"lua_additive_table\", namespace=\"App\", table-name=\"L\", handle-unlocalized=\"comment\")@\n"
tw_locale.close

ru_locale = File.new("#{addon}/Locales/#{addon}-ruRU.lua", modestring="w")
ru_locale << "local L = LibStub(\"AceLocale-3.0\"):NewLocale(\"#{addon}\",\"ruRU\")\n"
ru_locale << "if not L then return end\n"
ru_locale << "--@localization(locale=\"ruRU\", format=\"lua_additive_table\", namespace=\"App\", table-name=\"L\", handle-unlocalized=\"comment\")@\n"
ru_locale.close

# Generate the toc
toc <<"## Interface: 30100\n"
toc << "## Notes: FILL ME IN\n"
toc << "## Title: #{addon}\n"
toc << "## Author: AUTHOR\n"
toc << "## SavedVariables: #{addon}DB\n"
toc << "## X-Category: CATEGORY\n"
toc << "## Version: 1.0\n\n"
toc << "## OptionalDeps: Ace3\n\n"
toc << "embeds.xml\n"
toc << "Locales.xml\n"
toc << "#{addon}.lua\n"
toc.close()

# Generate the Locales file
locale_xml << "<Ui xmlns=\"http://www.blizzard.com/wow/ui/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"http://www.blizzard.com/wow/ui/../FrameXML/UI.xsd\">\n"
locale_xml <<	"\t<Script file=\"Locales\\#{addon}-enUS.lua\"/>\n"
locale_xml <<	"\t<Script file=\"Locales\\#{addon}-deDE.lua\"/>\n"
locale_xml <<	"\t<Script file=\"Locales\\#{addon}-esES.lua\"/>\n"
locale_xml <<	"\t<Script file=\"Locales\\#{addon}-esMX.lua\"/>\n"
locale_xml <<	"\t<Script file=\"Locales\\#{addon}-frFR.lua\"/>\n"
locale_xml <<	"\t<Script file=\"Locales\\#{addon}-koKR.lua\"/>\n"
locale_xml <<	"\t<Script file=\"Locales\\#{addon}-znCN.lua\"/>\n"
locale_xml <<	"\t<Script file=\"Locales\\#{addon}-znTW.lua\"/>\n"
locale_xml <<	"\t<Script file=\"Locales\\#{addon}-ruRU.lua\"/>\n"
locale_xml << "</Ui>\n"
locale_xml.close()

embeds << "<Ui xmlns=\"http://www.blizzard.com/wow/ui/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"http://www.blizzard.com/wow/ui/..\FrameXML\UI.xsd\">\n"
embeds << "\t<Include file=\"Libs\\Ace3\\Ace3.xml\"/>\n"
embeds << "</Ui>\n"
embeds.close

main << "local #{addon} = LibStub(\"AceAddon-3.0\"):NewAddon(\"#{addon}\",\"AceDB-3.0\")\n"
main << "local L = LibStub(\"AceLocale-3.0\"):GetLocale(\"#{addon}\",false)\n"
main.close
